@@ -12,10 +12,13 @@
 
 iso.lang <- function(x, glottolog.source = "modified") {
     if(typeof(x) == "list"){x <- unlist(x)}
-    ifelse(grepl(glottolog.source, "original"), glottolog <- lingtypology::glottolog.original,
-        glottolog <- lingtypology::glottolog.modified)
+    ifelse(grepl(glottolog.source, "original"),
+           glottolog <- lingtypology::glottolog.original,
+           glottolog <- lingtypology::glottolog.modified)
     vapply(x, function(y) {
-        ifelse(is.glottolog(y, response = TRUE, glottolog.source = glottolog.source) == TRUE,
-               glottolog[tolower(glottolog$language) %in% tolower(y), ]$iso, NA_character_)
+        ifelse(is.glottolog(y, response = TRUE,
+                            glottolog.source = glottolog.source) == TRUE,
+               glottolog[tolower(glottolog$language) %in% tolower(y), ]$iso,
+               NA_character_)
     }, character(1))
 }
